==> cmsmadesimple-1.5.3.tgz: cms/modules/FileManager/lang/ext/ca_ES.php <==
<?php
$lang['friendlyname'] = 'Gestor d&#039;arxius';
$lang['permission'] = '&Uacute;s del m&ograve;dul Gestor d&#039;arxius';
$lang['permissionadvanced'] = '&Uacute;s avan&ccedil;at del m&ograve;dul Gestor d&#039;arxius';
$lang['moddescription'] = 'Gesti&oacute; d&#039;arxius i dirctoris a la secci&oacute; de pujar arxius de cmsms';
$lang['installed'] = 'Versi&oacute; %s instal.lada del Gestor d&#039;arxius';
$lang['postinstall'] = 'S&#039;ha instal.lat el m&ograve;dul Gestor d&#039;arxius';
$lang['uninstalled'] = 'M&ograve;dul Gestor d&#039;arxius desinstal.lat';
$lang['really_uninstall'] = 'Est&agrave;s segur que vols desinstal.lar el m&ograve;dul Gestor d&#039;arxius';
$lang['upgraded'] = 'S&#039;ha actualitzat el m&ograve;dul Gestor d&#039;arxius a la versi&oacute; %s.';
$lang['fileview'] = 'Veure arxius';
$lang['switchtofileview'] = 'Canviar a vista d&#039;arxius';
$lang['settings'] = 'Configuraci&oacute;';
$lang['savesettings'] = 'Desar configuraci&oacute;';
$lang['filename'] = 'Nom d&#039;arxiu';
$lang['fileinfo'] = 'Informaci&oacute; d&#039;arxiu';
$lang['fileowner'] = 'Propietari d&#039;arxiu';
$lang['fileperms'] = 'Permsos';
$lang['filesize'] = 'Mida';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Accions';
$lang['delete'] = 'Esborrar';
$lang['notwritable'] = 'No es pot escriure';
$lang['filetoobig'] = '&eacute;s massa gran. Pujada cancel.lada';
$lang['unknown'] = 'Desconegut';
$lang['fileoutsideuploads'] = 'No tens acc&eacute;s a modificar arxius fora del directori de pujades! (Aix&ograve; requereix el perm&iacute;s Gesti&oacute; Avan&ccedil;ada d&#039;Arxius';
$lang['writable'] = 'Modificable';
$lang['writeprotected'] = 'Protegit de modificaci&oacute;';
$lang['bytes'] = 'bytes';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'arxius';
$lang['bytesin'] = 'bytes a';
$lang['in'] = 'en';
$lang['file'] = 'arxiu';
$lang['fileno'] = 'Arxiu n&ordm;';
$lang['subdirs'] = 'subdirectoris';
$lang['subdir'] = 'subdirectori';
$lang['and'] = 'i';
$lang['confirmsingledelete'] = 'N&#039;est&agrave;s segur?';
$lang['confirmsingledirdelete'] = 'Est&agrave;s segur que s&#039;hauria d&#039;esborrar aquest directori?';
$lang['dirtreedeletesuccess'] = 'El directori s&#039;ha esborrat correctament incloent el contingut.';
$lang['dirtreedeletefail'] = 'Hi ha hagut un error esborrant aquest directori. Malgrat tot, es podria haver esborrat part del contingut';
$lang['singlefiledeletesuccess'] = 'L&#039;arxiu s&#039;ha esborrat correctament.';
$lang['filedeletesuccess'] = 's&#039;ha esborrat correctament';
$lang['singlefiledeletefail'] = 'Hi ha hagut un error intentat esborrar l&#039;arxiu.';
$lang['filedeletefail'] = 'no s&#039;ha esborrat degut a un error';
$lang['singledirdeletesuccess'] = 'El directori s&#039;ha esborrat correctament';
$lang['singledirdeletefail'] = 'Hi ha hagut un error en esborrar el directori (est&agrave; buit?)';
$lang['deleteselected'] = 'Esborra els arxius triats';
$lang['confirmselected'] = 'N&#039;est&agrave;s segur?';
$lang['confirmdeleteselected'] = 'N&#039;est&agrave;s segur que els arxius triats s&#039;han d&#039;esborrar?';
$lang['deleteselectedcancelled'] = 'Esborrat dels arxius cancel.lat.';
$lang['recursetext'] = 'Ressegueix dins els subdirectoris';
$lang['nofilesselected'] = 'No s&#039;han triat arxius';
$lang['moveselected'] = 'Moure els arxius triats';
$lang['copyselected'] = 'Copia els arxius triats';
$lang['selecttargetdir'] = 'Tria el directori que es vol copiar/moure';
$lang['movedto'] = 'mogut a ';
$lang['copiedto'] = 'copiat a ';
$lang['couldnotmove'] = 'no s&#039;ha pogut moure';
$lang['couldnotcopy'] = 'no s&#039;ha pogut copiar';
$lang['rename'] = 'Renombrat';
$lang['newname'] = 'Nou nom:';
$lang['renamesuccess'] = 'Arxiu renombrat correctament.';
$lang['renamefailure'] = 'Ha fallat el canvi de nom';
$lang['renamecancelled'] = 'Renombrat cancel.lat';
$lang['owner'] = 'Propietari';
$lang['group'] = 'Grup';
$lang['others'] = 'Altres';
$lang['newpermissions'] = 'Nous permisos:';
$lang['setpermissions'] = 'Fixa permisos';
$lang['permissionstyle'] = 'Estil de permisos';
$lang['rwxstyle'] = 'estil rwx ';
$lang['755style'] = 'estil 755';
$lang['quickmode'] = 'Canvi r&agrave;pid de permisos (tipus 777)';
$lang['chmod'] = 'Canvia permisos';
$lang['chmodselected'] = 'Canvia permisos en arxius triats';
$lang['chmodsuccess'] = 'L&#039;arxiu t&eacute; els nous permisos ';
$lang['chmodfailure'] = 'Canvi de permisos d&#039;arxiu erroni';
$lang['chmodcancelled'] = 'Canvi de permisos cancel.lat';
$lang['dirchmodfailmulti'] = 'El canvi de permisos en el directori ha fallat, per&ograve; pot ser que algun dels arxius tingui els nous permisos';
$lang['dirchmodsuccessmulti'] = 'El canvi de permisos en el directori i el seu contingut ha estat correcte.';
$lang['dirchmodsuccess'] = 'El directori t&eacute; els nous permisos.';
$lang['dirchmodfailure'] = 'El canvi de permisos del directori ha fallat';
$lang['dirnotemptyconfirm'] = 'Aquest directori no est&agrave; buit. Est&agrave;s segur que el vols esborrar amb tot el seu contingut, incloent subdirectoris?';
$lang['dirtreedeletecancelled'] = 'Esborrat del directori cancel.lat';
$lang['imsure'] = 'N&#039;estic segur';
$lang['cancel'] = 'Cancel.la';
$lang['ok'] = 'OK.';
$lang['uploadnewfile'] = 'Puja nous arxiu(s):';
$lang['unpackafterupload'] = 'Provar de descomprimir l&#039;arxiu despr&eacute;s de pujar-lo(nom&eacute;s tgz i ma majoria dels arxius zip)?';
$lang['uploadsuccess'] = 's&#039;ha pujat correctament';
$lang['uploadfail'] = 'no s&#039;ha pogut pujar correctament';
$lang['unpacksuccess'] = 's&#039;ha descomprimit correctament';
$lang['unpackfail'] = ' ha fallat amb aquest error: ';
$lang['packfileopenfail'] = 'No s&#039;ha pogut obrir l&#039;arxiu empaquetat per desempaquetar (format no suportat?)';
$lang['packfilewritefail'] = 'No s&#039;ha pogut obrir l&#039;arxiu &amp;s per escriure';
$lang['currentpath'] = 'Cam&iacute; actual:';
$lang['newdirname'] = 'Crear un nou directori:';
$lang['newdirsuccess'] = 'El directori s&#039;ha creat correctament';
$lang['newdirfail'] = 'Ha ocorregut un error intentat crear un directori';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Mida d&#039;icones';
$lang['smallicons'] = 'Icones petites';
$lang['largeicons'] = 'Icones grans';
$lang['thousanddelimiter'] = 'Separador de mil.lers';
$lang['none'] = 'Cap';
$lang['showthumbnails'] = 'Mostrar contactes';
$lang['showthumbnailshelp'] = 'Habilitar aquesta opci&oacute; mostrar&agrave; com a contactes els arxius d&#039;imatge si existeixen, i ocultar&agrave; qualsevol arxiu tipus contacte que trobi. Deshabilitar l&#039;opci&oacute; mostrar&agrave; tots els arxius.';
$lang['uploadfilesto'] = 'Pujant arxius a:';
$lang['uploadview'] = 'Arxius a pujar';
$lang['uploadboxes'] = 'Nombre de caixes de pujada';
$lang['nothinguploaded'] = 'No s&#039;ha pujat res';
$lang['unsupportedarchive'] = 'Format d&#039;arxiu no suportat ';
$lang['uploadmethod'] = 'M&egrave;tode de pujada';
$lang['uploaderstandard'] = 'M&egrave;tode d&#039;entrada est&agrave;ndard d&#039;HTML (permet desempaquetat)';
$lang['enableadvanced'] = 'Activar el mode avan&ccedil;at?';
$lang['advancedhelp'] = 'Permet accedir a tot el sistema d&#039;arxius del cmsms, no nom&eacute;s /upload/ (si &eacute;s que est&agrave; perm&egrave;s)';
$lang['showhiddenfileshelp'] = 'Nom&eacute;s efectiu amb la modalitat avan&ccedil;ada activada';
$lang['showhiddenfiles'] = 'Mostrar arxius ocults';
$lang['settingsconfirmsingledelete'] = 'Realment vols esborrar un arxiu?';
$lang['settingssaved'] = 'Configuraci&oacute; desada';
$lang['help'] = '		<h3>Qu&egrave; fa aix&ograve;?</h3>
		<p>Aquest m&ograve;dul proporciona funcions de gesti&oacute; d&#039;arxius, eventualment i esperablement substitu&iuml;nt el for&ccedil;a antic sistema integrat de gesti&oacute; d&#039;arxius.</p>
		<h3>Com l&#039;utilitzo?</h3>
		<p>Tria&#039;l des del men&uacute; de contingut en l&#039;entorn d&#039;administraci&oacute;. Mentre l&#039;antic gestor d&#039;arxius encara sigui all&agrave;, has de triar l&#039;opci&oacute; de m&eacute;s avall.</p>';
$lang['utma'] = '156861353.1023133021.1231496674.1231496674.1231501779.2';
$lang['utmz'] = '156861353.1231496674.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/FileManager/lang/ext/ca_ES.php <==
<?php
$lang['friendlyname'] = 'Gestor d&#039;arxius';
$lang['permission'] = '&Uacute;s del m&ograve;dul Gestor d&#039;arxius';
$lang['permissionadvanced'] = '&Uacute;s avan&ccedil;at del m&ograve;dul Gestor d&#039;arxius';
$lang['moddescription'] = 'Gesti&oacute; d&#039;arxius i dirctoris a la secci&oacute; de pujar arxius de cmsms';
$lang['installed'] = 'Versi&oacute; %s instal.lada del Gestor d&#039;arxius';
$lang['postinstall'] = 'S&#039;ha instal.lat el m&ograve;dul Gestor d&#039;arxius';
$lang['uninstalled'] = 'M&ograve;dul Gestor d&#039;arxius desinstal.lat';
$lang['really_uninstall'] = 'Est&agrave;s segur que vols desinstal.lar el m&ograve;dul Gestor d&#039;arxius';
$lang['upgraded'] = 'S&#039;ha actualitzat el m&ograve;dul Gestor d&#039;arxius a la versi&oacute; %s.';
$lang['fileview'] = 'Veure arxius';
$lang['switchtofileview'] = 'Canviar a vista d&#039;arxius';
$lang['settings'] = 'Configuraci&oacute;';
$lang['savesettings'] = 'Desar configuraci&oacute;';
$lang['filename'] = 'Nom d&#039;arxiu';
$lang['fileinfo'] = 'Informaci&oacute; d&#039;arxiu';
$lang['fileowner'] = 'Propietari d&#039;arxiu';
$lang['fileperms'] = 'Permsos';
$lang['filesize'] = 'Mida';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Accions';
$lang['delete'] = 'Esborrar';
$lang['notwritable'] = 'No es pot escriure';
$lang['filetoobig'] = '&eacute;s massa gran. Pujada cancel.lada';
$lang['unknown'] = 'Desconegut';
$lang['fileoutsideuploads'] = 'No tens acc&eacute;s a modificar arxius fora del directori de pujades! (Aix&ograve; requereix el perm&iacute;s Gesti&oacute; Avan&ccedil;ada d&#039;Arxius';
$lang['writable'] = 'Modificable';
$lang['writeprotected'] = 'Protegit de modificaci&oacute;';
$lang['bytes'] = 'bytes';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'arxius';
$lang['bytesin'] = 'bytes a';
$lang['in'] = 'en';
$lang['file'] = 'arxiu';
$lang['fileno'] = 'Arxiu n&ordm;';
$lang['subdirs'] = 'subdirectoris';
$lang['subdir'] = 'subdirectori';
$lang['and'] = 'i';
$lang['confirmsingledelete'] = 'N&#039;est&agrave;s segur?';
$lang['confirmsingledirdelete'] = 'Est&agrave;s segur que s&#039;hauria d&#039;esborrar aquest directori?';
$lang['dirtreedeletesuccess'] = 'El directori s&#039;ha esborrat correctament incloent el contingut.';
$lang['dirtreedeletefail'] = 'Hi ha hagut un error esborrant aquest directori. Malgrat tot, es podria haver esborrat part del contingut';
$lang['singlefiledeletesuccess'] = 'L&#039;arxiu s&#039;ha esborrat correctament.';
$lang['filedeletesuccess'] = 's&#039;ha esborrat correctament';
$lang['singlefiledeletefail'] = 'Hi ha hagut un error intentat esborrar l&#039;arxiu.';
$lang['filedeletefail'] = 'no s&#039;ha esborrat degut a un error';
$lang['singledirdeletesuccess'] = 'El directori s&#039;ha esborrat correctament';
$lang['singledirdeletefail'] = 'Hi ha hagut un error en esborrar el directori (est&agrave; buit?)';
$lang['deleteselected'] = 'Esborra els arxius triats';
$lang['confirmselected'] = 'N&#039;est&agrave;s segur?';
$lang['confirmdeleteselected'] = 'N&#039;est&agrave;s segur que els arxius triats s&#039;han d&#039;esborrar?';
$lang['deleteselectedcancelled'] = 'Esborrat dels arxius cancel.lat.';
$lang['recursetext'] = 'Ressegueix dins els subdirectoris';
$lang['nofilesselected'] = 'No s&#039;han triat arxius';
$lang['moveselected'] = 'Moure els arxius triats';
$lang['copyselected'] = 'Copia els arxius triats';
$lang['selecttargetdir'] = 'Tria el directori que es vol copiar/moure';
$lang['movedto'] = 'mogut a ';
$lang['copiedto'] = 'copiat a ';
$lang['couldnotmove'] = 'no s&#039;ha pogut moure';
$lang['couldnotcopy'] = 'no s&#039;ha pogut copiar';
$lang['rename'] = 'Renombrat';
$lang['newname'] = 'Nou nom:';
$lang['renamesuccess'] = 'Arxiu renombrat correctament.';
$lang['renamefailure'] = 'Ha fallat el canvi de nom';
$lang['renamecancelled'] = 'Renombrat cancel.lat';
$lang['owner'] = 'Propietari';
$lang['group'] = 'Grup';
$lang['others'] = 'Altres';
$lang['newpermissions'] = 'Nous permisos:';
$lang['setpermissions'] = 'Fixa permisos';
$lang['permissionstyle'] = 'Estil de permisos';
$lang['rwxstyle'] = 'estil rwx ';
$lang['755style'] = 'estil 755';
$lang['quickmode'] = 'Canvi r&agrave;pid de permisos (tipus 777)';
$lang['chmod'] = 'Canvia permisos';
$lang['chmodselected'] = 'Canvia permisos en arxius triats';
$lang['chmodsuccess'] = 'L&#039;arxiu t&eacute; els nous permisos ';
$lang['chmodfailure'] = 'Canvi de permisos d&#039;arxiu erroni';
$lang['chmodcancelled'] = 'Canvi de permisos cancel.lat';
$lang['dirchmodfailmulti'] = 'El canvi de permisos en el directori ha fallat, per&ograve; pot ser que algun dels arxius tingui els nous permisos';
$lang['dirchmodsuccessmulti'] = 'El canvi de permisos en el directori i el seu contingut ha estat correcte.';
$lang['dirchmodsuccess'] = 'El directori t&eacute; els nous permisos.';
$lang['dirchmodfailure'] = 'El canvi de permisos del directori ha fallat';
$lang['dirnotemptyconfirm'] = 'Aquest directori no est&agrave; buit. Est&agrave;s segur que el vols esborrar amb tot el seu contingut, incloent subdirectoris?';
$lang['dirtreedeletecancelled'] = 'Esborrat del directori cancel.lat';
$lang['imsure'] = 'N&#039;estic segur';
$lang['cancel'] = 'Cancel.la';
$lang['ok'] = 'OK.';
$lang['uploadnewfile'] = 'Puja nous arxiu(s):';
$lang['unpackafterupload'] = 'Provar de descomprimir l&#039;arxiu despr&eacute;s de pujar-lo(nom&eacute;s tgz i ma majoria dels arxius zip)?';
$lang['uploadsuccess'] = 's&#039;ha pujat correctament';
$lang['uploadfail'] = 'no s&#039;ha pogut pujar correctament';
$lang['unpacksuccess'] = 's&#039;ha descomprimit correctament';
$lang['unpackfail'] = ' ha fallat amb aquest error: ';
$lang['packfileopenfail'] = 'No s&#039;ha pogut obrir l&#039;arxiu empaquetat per desempaquetar (format no suportat?)';
$lang['packfilewritefail'] = 'No s&#039;ha pogut obrir l&#039;arxiu &amp;s per escriure';
$lang['containsillegalchars'] = 'El nom d&#039;arxiu cont&eacute; almenys un car&agrave;cter il.legal (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Cam&iacute; actual:';
$lang['newdirname'] = 'Crear un nou directori:';
$lang['newdirsuccess'] = 'El directori s&#039;ha creat correctament';
$lang['newdirfail'] = 'Ha ocorregut un error intentat crear un directori';
$lang['invalidnewdir'] = 'El nom d&#039;un directori no pot contenir car&agrave;cters com ara /, \ o &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Mida d&#039;icones';
$lang['smallicons'] = 'Icones petites';
$lang['largeicons'] = 'Icones grans';
$lang['thousanddelimiter'] = 'Separador de mil.lers';
$lang['none'] = 'Cap';
$lang['space'] = 'espai';
$lang['showthumbnails'] = 'Mostrar contactes';
$lang['showthumbnailshelp'] = 'Habilitar aquesta opci&oacute; mostrar&agrave; com a contactes els arxius d&#039;imatge si existeixen, i ocultar&agrave; qualsevol arxiu tipus contacte que trobi. Deshabilitar l&#039;opci&oacute; mostrar&agrave; tots els arxius.';
$lang['uploadfilesto'] = 'Pujant arxius a:';
$lang['uploadview'] = 'Arxius a pujar';
$lang['uploadboxes'] = 'Nombre de caixes de pujada';
$lang['nothinguploaded'] = 'No s&#039;ha pujat res';
$lang['unsupportedarchive'] = 'Format d&#039;arxiu no suportat ';
$lang['uploadmethod'] = 'M&egrave;tode de pujada';
$lang['uploaderstandard'] = 'M&egrave;tode d&#039;entrada est&agrave;ndard d&#039;HTML (permet desempaquetat)';
$lang['enableadvanced'] = 'Activar el mode avan&ccedil;at?';
$lang['advancedhelp'] = 'Permet accedir a tot el sistema d&#039;arxius del cmsms, no nom&eacute;s /upload/ (si &eacute;s que est&agrave; perm&egrave;s)';
$lang['showhiddenfileshelp'] = 'Nom&eacute;s efectiu amb la modalitat avan&ccedil;ada activada';
$lang['showhiddenfiles'] = 'Mostrar arxius ocults';
$lang['settingsconfirmsingledelete'] = 'Realment vols esborrar un arxiu?';
$lang['settingssaved'] = 'Configuraci&oacute; desada';
$lang['help'] = '		<h3>Qu&egrave; fa aix&ograve;?</h3>
		<p>Aquest m&ograve;dul proporciona funcions de gesti&oacute; d&#039;arxius, eventualment i esperablement substitu&iuml;nt el for&ccedil;a antic sistema integrat de gesti&oacute; d&#039;arxius.</p>
		<h3>Com l&#039;utilitzo?</h3>
		<p>Tria&#039;l des del men&uacute; de contingut en l&#039;entorn d&#039;administraci&oacute;. Mentre l&#039;antic gestor d&#039;arxius encara sigui all&agrave;, has de triar l&#039;opci&oacute; de m&eacute;s avall.</p>';
$lang['utma'] = '156861353.3109145977533247500.1225311312.1256902475.1256908322.42';
$lang['utmz'] = '156861353.1254088757.35.2.utmccn=(referral)|utmcsr=66.147.244.155|utmcct=/~clubcocc/cmsmadesimple/install/index.php|utmcmd=referral';
$lang['qca'] = 'P0-894451108-1250455823820';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
